==> raise_utils-1.3.2.tar.gz: raise_utils-1.3.2/README.md <==
<p align="center">
<img src="http://ai4se.net/img/logo.png" height="80px" /><br />
<a href="http://ai4se.net">homepage</a>  | 
<a href="https://github.com/yrahul3910/raise/tree/master/docs">quick guide</a>  |
<a href="https://raise.readthedocs.io/en/latest/">docs</a>  |
<a href="https://github.com/yrahul3910/raise/blob/master/CHANGES.md">change log</a>  |
<a href="https://github.com/yrahul3910/raise/blob/master/LICENSE">license</a>  |
<a href="https://github.com/yrahul3910/raise/blob/master/CODE_OF_CONDUCT.md">contribute</a>  |
<a href="https://github.com/yrahul3910/raise/issues/">issues</a>  |
<a href="mailto:timm@ieee.org">contact</a>
</p>
<p align="center">
<img src="https://img.shields.io/badge/language-python-orange.svg">&nbsp;
<img src="https://img.shields.io/badge/license-LGPL-green.svg">&nbsp;
<a href="https://badge.fury.io/py/raise-utils"><img src="https://badge.fury.io/py/raise-utils.svg" alt="PyPI version" height="20"></a>
<a href="https://pepy.tech/project/raise-utils"><img src="https://pepy.tech/badge/raise-utils" /></a>
<a href='https://raise.readthedocs.io/en/latest/?badge=latest'>
    <img src='https://readthedocs.org/projects/raise/badge/?version=latest' alt='Documentation Status' />
</a>
<a href="https://travis-ci.org/yrahul3910/raise"><img src="https://travis-ci.org/yrahul3910/raise.svg?branch=master" /></a>
<a href="https://www.codacy.com/manual/yrahul3910/raise?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=yrahul3910/raise&amp;utm_campaign=Badge_Grade"><img src="https://app.codacy.com/project/badge/Grade/8352fafd16454ea995f43891d9571d22"/></a>&nbsp;
<a href="https://codecov.io/gh/yrahul3910/raise">
    <img src="https://codecov.io/gh/yrahul3910/raise/branch/master/graph/badge.svg?token=6U8KR6PYZA"/>
</a>&nbsp;
</p> <hr />

# The RAISE package

The RAISE package is an attempt to unify code, and incorporate PEP8 standards. The package takes a modular, object-oriented design, with each part of the ML pipeline encapsulated in a class. The purpose is to allow a streamlined, easy to read interface that allows for explainability of code, to enforce programming standards, and improve maintainability.

## Install

```
pip3 install raise-utils
```

## Python Support

Only Python 3 is supported, Python 2 is not. Because TensorFlow and sklearn do not yet support Python 3.9, this is not yet compatible with Python 3.9; please use an older version until then.

## Documentation

Read our docs [here](https://github.com/yrahul3910/raise/tree/master/docs).

==> raise_utils-1.6.2.tar.gz: raise_utils-1.6.2/README.md <==
<p align="center">
<img src="http://ai4se.net/img/logo.png" height="80px" /><br />
<a href="http://ai4se.net">homepage</a>  | 
<a href="https://github.com/yrahul3910/raise/tree/master/docs">quick guide</a>  |
<a href="https://raise.readthedocs.io/en/latest/">docs</a>  |
<a href="https://github.com/yrahul3910/raise/blob/master/CHANGES.md">change log</a>  |
<a href="https://github.com/yrahul3910/raise/blob/master/LICENSE">license</a>  |
<a href="https://github.com/yrahul3910/raise/blob/master/CODE_OF_CONDUCT.md">contribute</a>  |
<a href="https://github.com/yrahul3910/raise/issues/">issues</a>  |
<a href="mailto:timm@ieee.org">contact</a>
</p>
<p align="center">
<img src="https://img.shields.io/badge/language-python-orange.svg">&nbsp;
<img src="https://img.shields.io/badge/license-LGPL-green.svg">&nbsp;
<a href="https://badge.fury.io/py/raise-utils"><img src="https://badge.fury.io/py/raise-utils.svg" alt="PyPI version" height="20"></a>
<a href="https://pepy.tech/project/raise-utils"><img src="https://pepy.tech/badge/raise-utils" /></a>
<a href='https://raise.readthedocs.io/en/latest/?badge=latest'>
    <img src='https://readthedocs.org/projects/raise/badge/?version=latest' alt='Documentation Status' />
</a>
<a href="https://circleci.com/gh/yrahul3910/raise/tree/master"><img src="https://circleci.com/gh/yrahul3910/raise/tree/master.svg?style=svg" alt="CircleCI" /></a>
<a href="https://www.codacy.com/manual/yrahul3910/raise?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=yrahul3910/raise&amp;utm_campaign=Badge_Grade"><img src="https://app.codacy.com/project/badge/Grade/8352fafd16454ea995f43891d9571d22"/></a>&nbsp;
<a href="https://codecov.io/gh/yrahul3910/raise">
    <img src="https://codecov.io/gh/yrahul3910/raise/branch/master/graph/badge.svg?token=6U8KR6PYZA"/>
</a>&nbsp;
</p> <hr />

# The RAISE package

The RAISE package is an attempt to unify code, and incorporate PEP8 standards. The package takes a modular, object-oriented design, with each part of the ML pipeline encapsulated in a class. The purpose is to allow a streamlined, easy to read interface that allows for explainability of code, to enforce programming standards, and improve maintainability.

## Install

```
pip3 install raise-utils
```

## Python Support

Only Python 3 is supported, Python 2 is not. Because TensorFlow and sklearn do not yet support Python 3.9, this is not yet compatible with Python 3.9; please use an older version until then.

## Documentation

Read our docs [here](https://github.com/yrahul3910/raise/tree/master/docs).
